We are dealing with CTS, not DSR here (we dealt with DSR a few lines
above), so set appropriate bits.

Reported-by: Kevin Cernekee <cerne...@chromium.org>
Signed-off-by: Dmitry Torokhov <d...@chromium.org>
---
 drivers/tty/serial/8250/8250_dw.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/tty/serial/8250/8250_dw.c 
b/drivers/tty/serial/8250/8250_dw.c
index 2ab229d..eb0a511 100644
--- a/drivers/tty/serial/8250/8250_dw.c
+++ b/drivers/tty/serial/8250/8250_dw.c
@@ -355,9 +355,9 @@ static int dw8250_probe_of(struct uart_port *p,
        }
 
        if (of_property_read_bool(np, "cts-override")) {
-               /* Always report DSR as active */
-               data->msr_mask_on |= UART_MSR_DSR;
-               data->msr_mask_off |= UART_MSR_DDSR;
+               /* Always report CTS as active */
+               data->msr_mask_on |= UART_MSR_CTS;
+               data->msr_mask_off |= UART_MSR_DCTS;
        }
 
        if (of_property_read_bool(np, "ri-override")) {
-- 
2.2.0.rc0.207.ga3a616c


-- 
Dmitry
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to